package HTTP::Balancer::Command::Add;
use Modern::Perl;
use Moose;
with qw( HTTP::Balancer::Role::Stem );

sub run {
    my ($self, ) = @_;

}

1;
